# Supported Color Spaces

ColorAide Extras adds a number of additional color spaces to ColorAide. Some are just spaces that are less practical
to use for common cases, some are just interesting for specific applications, some are implemented just for history,
and some are fairly new and a bit experimental.

Click a color space to learn more.

/// html | div.data-search-exclude
```diagram
%%{init: {"flowchart": {"useMaxWidth": true}}}%%
flowchart TB

    uvw --- xyz-d65

    xyz-d65(XYZ D65)
    uvw(CIE 1964 UVW)

    click xyz-d65 "https://facelessuser.github.io/coloraide/colors/xyz_d65/" _blank
    click uvw "./uvw" _self
```
///
